@@ -3,8 +3,9 @@ Main interface for elastictranscoder service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elastictranscoder import (
+    from mypy_boto3_elastictranscoder import (
         Client,
         ElasticTranscoderClient,
         JobCompleteWaiter,
@@ -12,7 +13,7 @@ Usage::
         ListJobsByStatusPaginator,
         ListPipelinesPaginator,
         ListPresetsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -25,6 +26,7 @@ Usage::
     list_jobs_by_status_paginator: ListJobsByStatusPaginator = client.get_paginator("list_jobs_by_status")
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     list_presets_paginator: ListPresetsPaginator = client.get_paginator("list_presets")
+    ```
 """
 from mypy_boto3_elastictranscoder.client import (
     ElasticTranscoderClient,
